## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)
library(MultiModalGraphics)
library(ComplexHeatmap)
library(dplyr)

## ----informative-heatmap-example----------------------------------------------
informative_heatmap_df <- get_informative_heatmap_df()
print(informative_heatmap_df)

## ----clear-scatterplot-example------------------------------------------------
clear_scatterplot_df <- get_clear_scatterplot_df()
print(clear_scatterplot_df)

## ----multifeature-grid-example------------------------------------------------
multifeature_grid_df <- get_multifeature_grid_df()
print(multifeature_grid_df)

## ----load-data----------------------------------------------------------------
plotdata <- get_clear_scatterplot_df()

scatterplotObject <- ClearScatterplot(
  data = plotdata,
  logFoldChange = "log2fc",
  timePointColumn = "timePoint",
  timePointLevels = c("T10R1", "T5R1")
)

## ----create-plot--------------------------------------------------------------
scattered_plot <-
  createPlot(
    scatterplotObject,
    color1 = "cornflowerblue",
    color2 = "grey",
    color3 = "indianred",
    highLog2fc = 0.585,
    lowLog2fc = -0.585,
    negLog10pValue = 1.301,
    expressionDirection = "regulation",
    negativeLogPValue = "negLog10p",
    timeVariable = "reg_time_org",
    xAxis = "organ",
    yAxis = "timePoint"
  )

## ----display-plot-------------------------------------------------------------
scattered_plot  # Display the plot

## ----load-heatmap-data--------------------------------------------------------
informative_heatmap <- get_informative_heatmap_df()
informative_heatmap_matrix <- as.matrix(informative_heatmap)
group_val <- informative_heatmap_matrix[, 1:3]
p_val <- informative_heatmap_matrix[, 4:6]

## ----create-heatmap-----------------------------------------------------------
htmp_plus <- InformativeHeatmap(group_val,
                                unit_val = 7,
                                pch_val = 16,
                                significant_color = "black",
                                trending_color = "turquoise",
                                significant_pvalue = 0.05,
                                trending_pvalue = 0.1,
                                significance_level = p_val,
                                row_title = "Genes",
                                column_title = "Value and Significance",
                                cluster_rows = TRUE,
                                show_row_names = TRUE,
                                row_names_side = "left",
                                column_names_rot = 45,
                                row_dend_reorder = TRUE,
                                rect_gp = gpar(col = "white", lwd = 2))

## ----draw-heatmap-------------------------------------------------------------
draw(getHeatmapObject(htmp_plus))

## ----example-data-------------------------------------------------------------
data <- get_multifeature_grid_df()

## ----create-grid--------------------------------------------------------------
mg <- MultifeatureGrid(data)

## ----plot-heatmap, fig.width=10, fig.height=8---------------------------------
plot_heatmap(mg, independantVariable = "tissue")

## ----echo=FALSE---------------------------------------------------------------
sessionInfo()

